==> vue-dept-3.22.1.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import "@opentinyvue/vue-theme/dept/index.css";
var template = function template2(mode) {
  var _process$env;
  typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  return PcTemplate;
};
var Dept = defineComponent({
  name: $prefix + "Dept",
  props: _extends({}, $props, {
    modelValue: String,
    disabled: {
      type: Boolean,
      default: false
    },
    autoSelect: {
      type: Boolean,
      default: true
    },
    size: String,
    fetchDeptList: Function,
    fetchDeptByValue: Function,
    fetchDept: Function,
    beforeConfirm: Function,
    title: {
      type: String,
      default: ""
    },
    displayOnly: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "3.undefined";
Dept.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
Dept.install = function(Vue) {
  Vue.component(Dept.name, Dept);
};
Dept.version = version;
export {
  Dept as default
};

==> vue-dept-3.23.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import "@opentinyvue/vue-theme/dept/index.css";
var template = function template2(mode) {
  var _process$env;
  typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  return PcTemplate;
};
var Dept = defineComponent({
  name: $prefix + "Dept",
  props: _extends({}, $props, {
    modelValue: String,
    disabled: {
      type: Boolean,
      default: false
    },
    autoSelect: {
      type: Boolean,
      default: true
    },
    size: String,
    fetchDeptList: Function,
    fetchDeptByValue: Function,
    fetchDept: Function,
    beforeConfirm: Function,
    title: {
      type: String,
      default: ""
    },
    displayOnly: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "3.23.0";
Dept.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
Dept.install = function(Vue) {
  Vue.component(Dept.name, Dept);
};
Dept.version = version;
export {
  Dept as default
};
